@@ -3,20 +3,29 @@
 from ..util import client, formater, list2table, result_cache
 from terminal import bold, magenta, white, blue, green,red, yellow
 from ..const import CMD
+from batchcompute.utils.jsonizable import BatchEncoder
+import json
 
 PROGRESS_LEN = 70
 
-def all(clusterId=None, description=False, log=False):
+def all(clusterId=None, groupName=None, description=False, log=False, show_json=False):
     if clusterId:
-        get(clusterId, description, log)
+        if groupName:
+            getGroupDetail(clusterId, groupName)
+        else:
+            get(clusterId, description, log, show_json)
     else:
-        list()
+        list(show_json)
 
 
-def list():
+def list(show_json=False):
 
     result = client.list_clusters()
 
+    if show_json:
+        print(json.dumps(result, indent=2, cls=BatchEncoder))
+        return
+
     arr = formater.items2arr(result.get('Items'))
 
     result_len = len(arr)
@@ -50,12 +59,16 @@ def list():
 
     print(white('\n  type "%s c <Id|No.>" to show cluster detail\n' % (CMD)))
 
-def get(clusterId, descOnly=False, oplog=False):
+def get(clusterId, descOnly=False, oplog=False, show_json=False):
     clusterId = result_cache.get(clusterId, 'clusters')
 
     print(white('exec: bcs c %s' % clusterId))
     result = client.get_cluster(clusterId)
 
+    if show_json:
+        print(result)
+        return
+
     if descOnly:
         print(result)
         return
@@ -150,27 +163,8 @@ def get(clusterId, descOnly=False, oplog=False):
     groups = []
     total_desired_vm_count = 0
     for groupName in result.Groups:
-        v = formater.to_dict(result.Groups[groupName])
-        v['Name'] = groupName
-        v['VMCount'] = '%s / %s' % (v['ActualVMCount'],v['DesiredVMCount'])
-        ins = client.get_ins_type_map().get(v['InstanceType'])
-        if ins:
-            v['InstanceType/cpu/mem'] = '%s, %sCores, %sGB' % (v['InstanceType'], ins['cpu'], ins['memory'])
-        else:
-            v['InstanceType/cpu/mem'] = v['InstanceType']
-
-        if v.get('Disks'):
-            if v['Disks'].get('SystemDisk'):
-                v['SystemDisk'] = '%s:%sGB' %(v['Disks']['SystemDisk']['Type'], str(v['Disks']['SystemDisk']['Size']) )
-            else:
-                v['SystemDisk'] = ''
-            if v['Disks'].get('DataDisk'):
-                v['DataDisk'] = '%s:%sGB:%s' %( v['Disks']['DataDisk']['Type'] , v['Disks']['DataDisk']['Size'], v['Disks']['DataDisk']['MountPoint'])
-            else:
-                v['DataDisk'] = ''
-        else:
-            v['SystemDisk'] = ''
-            v['DataDisk'] = ''
+        v = format_group_info(groupName, result.Groups)
+        priceLimit = v.get('SpotPriceLimit') or 0
 
         groups.append(v)
         total_desired_vm_count = total_desired_vm_count + v['DesiredVMCount']
@@ -218,7 +212,7 @@ def get(clusterId, descOnly=False, oplog=False):
 
     # print groups
     print('%s' % bold(magenta('Groups:')))
-    list2table.print_table(groups, ['Name','VMCount','InstanceType/cpu/mem', 'ResourceType','SystemDisk', 'DataDisk'])
+    list2table.print_table(groups, ['Name','VMCount','InstanceType/cpu/mem', ('ResourceType/SpotPrice','ResourceType/PriceLimit' if priceLimit>0 else 'ResourceType'),'SystemDisk', 'DataDisk'])
 
     # OperationLogs
     if oplog:
@@ -227,6 +221,75 @@ def get(clusterId, descOnly=False, oplog=False):
 
     #print(result)
 
+def getGroupDetail(clusterId, groupName):
+    clusterId = result_cache.get(clusterId, 'clusters')
+
+    groupName = result_cache.get(groupName, 'groups')
+
+
+    print(white('exec: bcs c %s %s' % (clusterId,groupName)))
+
+    result = client.get_cluster(clusterId)
+
+    item = format_group_info(groupName, result.Groups)
+
+    item = formater.to_dict(item)
+
+    priceLimit = item.get('SpotPriceLimit') or 0
+
+    list2table.print_table([item], ['Name', 'VMCount', 'InstanceType/cpu/mem', (
+    'ResourceType/SpotPrice', 'ResourceType/PriceLimit' if priceLimit > 0 else 'ResourceType'), 'SystemDisk',
+                                    'DataDisk'])
+
+    # for (k,v) in groupInfo.items():
+    #     print('%s: %s' % (blue(k),v))
+
+    ## cluster instances
+    result1 = client.list_cluster_instances(clusterId, groupName)
+
+    instances = formater.items2arr(result1.get('Items'))
+    instances = formater.format_date_in_arr(instances, ['CreationTime'])
+
+    result_cache.save(instances, 'Id', 'cluster_instances')
+
+    # print groups
+    print('%s' % bold(magenta('Instances:')))
+    list2table.print_table(instances, ['Id', 'HostName', 'IpAddress','InstancePassword',
+                                       ('State','State', formater.get_cluster_state),
+                                    'CreationTime',('CreationTimeFromNow','FromNow')])
+
+def format_group_info(groupName, groups):
+    v = formater.to_dict(groups[groupName])
+    v['Name'] = groupName
+    v['VMCount'] = '%s / %s' % (v['ActualVMCount'], v['DesiredVMCount'])
+    ins = client.get_ins_type_map().get(v['InstanceType'])
+    if ins:
+        v['InstanceType/cpu/mem'] = '%s, %sCores, %sGB' % (v['InstanceType'], ins['cpu'], ins['memory'])
+    else:
+        v['InstanceType/cpu/mem'] = v['InstanceType']
+
+    if v.get('Disks'):
+        if v['Disks'].get('SystemDisk'):
+            v['SystemDisk'] = '%s:%sGB' % (v['Disks']['SystemDisk']['Type'], str(v['Disks']['SystemDisk']['Size']))
+        else:
+            v['SystemDisk'] = ''
+        if v['Disks'].get('DataDisk'):
+            v['DataDisk'] = '%s:%sGB:%s' % (
+            v['Disks']['DataDisk']['Type'], v['Disks']['DataDisk']['Size'], v['Disks']['DataDisk']['MountPoint'])
+        else:
+            v['DataDisk'] = ''
+    else:
+        v['SystemDisk'] = ''
+        v['DataDisk'] = ''
+
+    priceLimit = v.get('SpotPriceLimit') or 0
+    if v['ResourceType'] == 'Spot' and priceLimit > 0:
+        v['ResourceType/SpotPrice'] = '%s, <=%s' % (v['ResourceType'], priceLimit)
+    else:
+        v['ResourceType/SpotPrice'] = v['ResourceType']
+
+    return v
+
 def sort_cluster_list(arr):
     others_arr = []
     deleting_arr = []
