@@ -41,7 +41,8 @@ def create_cluster(clusterName, image=None, type=None, nodes=1, description='',
         }
         cluster_desc['Configs'] = {
             'Mounts': {
-                'NAS':{}
+                'NAS':{},
+                'Entries': []
             },
             'Disks': {}
             # 'Networks': {
@@ -95,7 +96,12 @@ def create_cluster(clusterName, image=None, type=None, nodes=1, description='',
             cluster_desc['Notification']['Topic']['Events'] = notification_events
 
         # vpc
-        vpc_cidr_block = vpc_cidr_block if vpc_cidr_block else config.getConfigs(config.COMMON, ['vpc_cidr_block']).get('vpc_cidr_block')
+        if vpc_cidr_block in util.FALSE_ARR:
+            vpc_cidr_block = None
+        elif vpc_cidr_block:
+            pass
+        else:
+            vpc_cidr_block = config.getConfigs(config.COMMON, ['vpc_cidr_block']).get('vpc_cidr_block')
 
         if vpc_cidr_block:
             if not cluster_desc['Configs'].get('Networks'):
@@ -130,20 +136,24 @@ def getClusterJSON(filePath):
         s = json.loads(f.read())
     return s
 def trans_mount(s):
-    return util.trans_mount(s)
+    return util.trans_mount_dup(s)
+
 def trans_schedule_type(s):
     if s not in ['LowLatency','Poll','Push']:
         raise Exception('Invalid schedule_type')
     return s
 
-def extend_mount(desc, mount_m):
-    desc['Configs']['Mounts']['Entries'] = []
-    for k, v in mount_m.items():
-        if k.startswith('oss://') or k.startswith('nas://'):
+
+
+def extend_mount(desc, mounts):
+
+    for n in mounts:
+        if n['Source'].startswith('oss://') or n['Source'].startswith('nas://'):
+
             desc['Configs']['Mounts']['Entries'].append({
-                "Destination": v,
-                "Source": k,
-                "WriteSupport": k.endswith('/')
+                "Destination": n['Destination'],
+                "Source": n['Source'],
+                "WriteSupport": n['WriteSupport']
             })
 
 def trans_image(image):
