@@ -6,7 +6,8 @@ import re
 FALSE_ARR = ['', 'null', 'None', 'false', 'False','0']
 
 def all(region=None, osspath=None, locale=None, image=None, type=None, cluster=None, qsubuser=None, vpc_cidr_block=None, version=None, ssl=None, god=None):
-    if not region and not osspath and not locale and not image and not type and not cluster and not qsubuser and not vpc_cidr_block and not version and not ssl and not god:
+    if not region and not osspath and not locale and not image and not type and not cluster and not qsubuser and\
+        not vpc_cidr_block and not version and not ssl and not god:
         show_config()
     else:
         if region:
@@ -29,6 +30,7 @@ def all(region=None, osspath=None, locale=None, image=None, type=None, cluster=N
             update_qsubuser(qsubuser)
         if vpc_cidr_block:
             update_vpc_cidr_block(vpc_cidr_block)
+            
         if god:
             update_god(god)
         print(green('done'))
@@ -52,7 +54,6 @@ def update_region(region):
 
     util.check_default_osspath(m)
 
-
 def update_vpc_cidr_block(vpc_cidr_block):
     m = config.getConfigs(config.COMMON)
 
