@@ -45,6 +45,13 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
 
     job_desc = trans_file_to_job_desc(file, not show_json and not show_dag)
 
+    if vpc_cidr_block in util.FALSE_ARR:
+        vpc_cidr_block = None
+    elif vpc_cidr_block:
+        pass
+    else:
+        vpc_cidr_block = config.getConfigs(config.COMMON, ['vpc_cidr_block']).get('vpc_cidr_block')
+    
     opt = {
         'cmd': cmd,
         'job_name': job_name,
@@ -87,9 +94,8 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'nas_file_system': nas_file_system,
 
         'vpc_id': vpc_id,
-        'vpc_cidr_block': vpc_cidr_block if vpc_cidr_block else config.getConfigs(config.COMMON, ['vpc_cidr_block']).get('vpc_cidr_block'),
+        'vpc_cidr_block': vpc_cidr_block,
         'spot_price_limit': spot_price_limit
-
     }
 
     job_desc = fix_by_opt(job_desc, opt, not show_json and show_dag)
@@ -330,9 +336,9 @@ def fix_by_opt(desc, opt, check_cluster):
 
 
         if opt.get('mount'):
-            extend_mount(task_desc, trans_mount(opt['mount']))
+            extend_mount_dup(task_desc, trans_mount_dup(opt['mount']))
         if opt.get('read_mount'):
-            extend_mount(task_desc, trans_mount(opt['read_mount']))
+            extend_mount_dup(task_desc, trans_mount_dup(opt['read_mount']))
 
 
 
@@ -386,6 +392,25 @@ def extend_mount(desc, mount_m):
     desc['Mounts']['Entries'] = t
 
 
+def extend_mount_dup(desc, mounts):
+    if not desc['Mounts'].get('Entries'):
+        desc['Mounts']['Entries'] = []
+
+    # 去重
+    m = {}
+    for n in desc['Mounts']['Entries']:
+        m[n['Source']+'^^^'+n['Destination']]=n
+
+
+    for n in mounts:
+        m[n['Source'] + '^^^' + n['Destination']] = n
+
+    t = []
+    for (k, v) in m.items():
+        t.append(v)
+
+    desc['Mounts']['Entries'] = t
+
 def trans_file_to_job_desc(file, check_cluster):
     cf = ConfigParser.ConfigParser()
     # parse file
@@ -471,9 +496,9 @@ def trans_file_to_job_desc(file, check_cluster):
 
 
             if cf.has_option(DEFAULT,'mount'):
-                extend_mount(task_desc , trans_mount(cf.get(DEFAULT,'mount')))
+                extend_mount_dup(task_desc , trans_mount_dup(cf.get(DEFAULT,'mount')))
             if cf.has_option(DEFAULT,'read_mount'):
-                extend_mount(task_desc, trans_mount(cf.get(DEFAULT,'read_mount')))
+                extend_mount_dup(task_desc, trans_mount_dup(cf.get(DEFAULT,'read_mount')))
 
 
 
@@ -576,7 +601,7 @@ def trans_file_to_job_desc(file, check_cluster):
                 extend(task_desc['AutoCluster']['UserData'], trans_user_data(cf.get(sec, 'user_data')))
 
             # vpc
-            if cf.has_option(sec, 'vpc_cidr_block'):
+            if cf.has_option(sec, 'vpc_cidr_block') and cf.get(sec, 'vpc_cidr_block') not in util.FALSE_ARR:
                 if not task_desc['AutoCluster'].get('Configs'):
                     task_desc['AutoCluster']['Configs'] = {}
                 if not task_desc['AutoCluster']['Configs'].get('Networks'):
@@ -624,10 +649,10 @@ def trans_file_to_job_desc(file, check_cluster):
 
 
         if cf.has_option(sec, 'mount'):
-            extend_mount(task_desc, trans_mount(cf.get(sec, 'mount')))
+            extend_mount_dup(task_desc, trans_mount_dup(cf.get(sec, 'mount')))
 
         if cf.has_option(sec,'read_mount'):
-            extend_mount(task_desc, trans_mount(cf.get(sec,'read_mount')))
+            extend_mount_dup(task_desc, trans_mount_dup(cf.get(sec,'read_mount')))
 
 
 
@@ -658,14 +683,8 @@ def extend(obj, obj2):
     return obj
 
 def trans_deps(deps):
-    # A->b,c;d->e,f
-    parts = deps.strip(';').split(';')
-    m = {}
-    for part in parts:
-      if '->' in part:
-        [k,v] = part.split('->')
-        m[k] = [x.strip() for x in v.split(',')]
-    return m
+    return util.trans_deps(deps)
+
 
 def trans_cluster(cluster, image=None, type=None, check_cluster=True):
     obj = util.parse_cluster_cfg(cluster, check_cluster)
@@ -720,6 +739,8 @@ def trans_env(s):
 
 def trans_mount(s):
     return util.trans_mount(s)
+def trans_mount_dup(s):
+    return util.trans_mount_dup(s)
 
 
 def trans_priority(p=None):
