@@ -8,7 +8,7 @@ import json
 import tarfile
 from batchcompute_cli.const import CMD
 import shutil
-from ..const import TEMPLATE_GATK_BUCKETS
+from ..const import TEMPLATE_GATK_BUCKETS,PY2,PY3
 
 
 def trans_jobId(job=None):
@@ -44,10 +44,31 @@ def gen(location=None, type="empty"):
         add_oss2(cur_path, dist)
 
 
+    ########################
+    ins_types = (client.list_instance_types() or [])
+
+    # sort
+    if PY2:
+        ins_types.sort(cmp=_ins_types_cmp)
+    else:
+        ins_types.sort(key= _ins_types_cmp2)
+
+
+    spot_ins_types = (client.list_spot_instance_types() or [])
+
+    # sort
+    if PY2:
+        spot_ins_types.sort(cmp=_ins_types_cmp )
+    else:
+        spot_ins_types.sort(key= _ins_types_cmp2 )
+
+    ############################
+
+
     if type=='gatk':
-        replaceTemplate4GATK(dist)
+        replaceTemplate4GATK(dist, ins_types, spot_ins_types)
     elif type=='wdl':
-        replaceTemplate4WDL(dist)
+        replaceTemplate4WDL(dist, ins_types, spot_ins_types)
     else:
         # update job.json set imageId: m-28sm4m6ez
         update_image_n_instype(os.path.join(dist,'job.json'))
@@ -55,7 +76,21 @@ def gen(location=None, type="empty"):
     print(green('Done'))
 
 
+def _ins_types_cmp(a,b):
+    if 'bcs.' in a.get('name'):
+        return 1
+    if 'sn1ne.' in b.get('name') or 'sn2ne.' in b.get('name'):
+        return 1
+    return -1
 
+def _ins_types_cmp2(n):
+
+    if 'bcs.' in n.get('name'):
+        return 1
+    elif 'ecs.sn1ne.' in n.get('name') or 'ecs.sn2ne.' in n.get('name'):
+        return -1
+    else:
+        return 0
 
 def update_image_n_instype(p):
     obj = {}
@@ -121,50 +156,51 @@ def __get_location(location):
 ##############################
 
 
-def get_instance_type(arr, cpu,mem):
+def get_instance_type(arr, cpu, mem):
 
     for n in arr:
        if n.get('cpu')>= int(cpu) and n.get('memory') >= int(mem):
            return n.get('name')
     return arr[-1].get('name')
 
-def _ins_types_cmp(a,b):
-    if 'bcs.' in a.get('name'):
-        return 1
-    if 'sn1ne.' in b.get('name') or 'sn2ne.' in b.get('name'):
-        return 1
-    return -1
 
 
-def replaceTemplate4GATK(dist):
+def replaceTemplate4GATK(dist, ins_types, spot_ins_types):
+    # main.sh
+    _replace_template(os.path.join(dist, 'fastq-to-ubam', 'main.sh'), ins_types, spot_ins_types)
 
     # main.sh
-    _replace_template(os.path.join(dist, 'gatk4-data-processing', 'main.sh'))
+    _replace_template(os.path.join(dist, 'gatk4-data-processing', 'main.sh'), ins_types, spot_ins_types)
     # inputs
     _replace_template(os.path.join(dist, 'gatk4-data-processing','src',
-                                   'processing-for-variant-discovery-gatk4.hg38.wgs.inputs.json'))
+                                   'processing-for-variant-discovery-gatk4.hg38.wgs.inputs.json'), ins_types, spot_ins_types)
+    _replace_template(os.path.join(dist, 'gatk4-data-processing', 'src',
+                                   'processing-for-variant-discovery-gatk4.hg38.wgs.inputs.30x.ondemand.json'), ins_types, spot_ins_types)
+    _replace_template(os.path.join(dist, 'gatk4-data-processing', 'src',
+                                   'processing-for-variant-discovery-gatk4.hg38.wgs.inputs.30x.spot.json'), ins_types, spot_ins_types)
 
     # main.sh2
-    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'main.sh'))
+    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'main.sh'), ins_types, spot_ins_types)
     # inputs2
     _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels','src',
-                           'haplotypecaller-gvcf-gatk4.hg38.wgs.inputs.json'))
+                           'haplotypecaller-gvcf-gatk4.hg38.wgs.inputs.json'), ins_types, spot_ins_types)
 
+    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels','src',
+                           'haplotypecaller-gvcf-gatk4.hg38.wgs.inputs.30x.ondemand.json'), ins_types, spot_ins_types)
+    _replace_template(os.path.join(dist, 'gatk4-germline-snps-indels', 'src',
+                                   'haplotypecaller-gvcf-gatk4.hg38.wgs.inputs.30x.spot.json'), ins_types, spot_ins_types)
 
-
-def replaceTemplate4WDL(dist):
+def replaceTemplate4WDL(dist, ins_types, spot_ins_types):
 
 
     # main.sh
-    _replace_template(os.path.join(dist, 'main.sh'))
-    _replace_template(os.path.join(dist, 'src', 'inputs.json'))
+    _replace_template(os.path.join(dist, 'main.sh'), ins_types, spot_ins_types)
+    _replace_template(os.path.join(dist, 'src', 'inputs.json'), ins_types, spot_ins_types)
 
 
-def _replace_template(p):
-    ins_types = (client.list_instance_types() or [])
+def _replace_template(p, ins_types, spot_ins_types):
+
 
-    # sort
-    ins_types.sort(cmp=_ins_types_cmp)
 
     bucket = TEMPLATE_GATK_BUCKETS.get(config.getRegion())
 
@@ -184,8 +220,18 @@ def _replace_template(p):
         str = str.replace('#{{INSTANCE_TYPE:8:16}}', get_instance_type(ins_types, 8, 16))
         str = str.replace('#{{INSTANCE_TYPE:16:32}}', get_instance_type(ins_types, 16, 32))
         str = str.replace('#{{INSTANCE_TYPE:8:32}}', get_instance_type(ins_types, 8, 32))
+        str = str.replace('#{{INSTANCE_TYPE:32:64}}', get_instance_type(ins_types, 32, 64))
         str = str.replace('#{{INSTANCE_TYPE:32:128}}', get_instance_type(ins_types, 32, 128))
 
+        str = str.replace('#{{SPOT_INSTANCE_TYPE:2:4}}', get_instance_type(spot_ins_types, 2, 4))
+        str = str.replace('#{{SPOT_INSTANCE_TYPE:4:8}}', get_instance_type(spot_ins_types, 4, 8))
+        str = str.replace('#{{SPOT_INSTANCE_TYPE:4:16}}', get_instance_type(spot_ins_types, 4, 16))
+        str = str.replace('#{{SPOT_INSTANCE_TYPE:8:16}}', get_instance_type(spot_ins_types, 8, 16))
+        str = str.replace('#{{SPOT_INSTANCE_TYPE:16:32}}', get_instance_type(spot_ins_types, 16, 32))
+        str = str.replace('#{{SPOT_INSTANCE_TYPE:8:32}}', get_instance_type(spot_ins_types, 8, 32))
+        str = str.replace('#{{SPOT_INSTANCE_TYPE:32:64}}', get_instance_type(spot_ins_types, 32, 64))
+        str = str.replace('#{{SPOT_INSTANCE_TYPE:32:128}}', get_instance_type(spot_ins_types, 32, 128))
+
         str = str.replace('#{{GENOMICS_PUBLIC_BUCKET}}', bucket)
 
         str = str.replace('#{{DEFAULT_OSS_PATH}}', oss_path)
