@@ -28,8 +28,8 @@ def getJSON():
                 "god": "use god mode, scope:[true|false]",
                 'ssl': 'requesting with https, scope:[true|false]',
                 'qsubuser': 'set user for qsub, if unspecified, default:root',
-                'vpc_cidr_block': '''specify CIDR IP block for VPC, usually: 192.168.0.0/16,
-                                       if you don't specify or it is set to false, then use the classic network'''
+                'vpc_cidr_block': '''specify CIDR IP block for VPC, default: 192.168.0.0/16, if it is set to false, 
+                                    then use the classic network'''
             }
         },
         'info': {
@@ -147,10 +147,10 @@ def getJSON():
                 'notification_endpoint': "MNS Endpoint, see in MNS web console.",
                 'mount': """optional,mount nas path to local file system in read/write mode,
                                              or mount oss path to local file system in read mode.
-                                             format: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
-                                             example: nas://path/to/mount/:/home/admin/dir/.
+                                             format: <nas_path|oss_path>:<dir_path>[:write_support],multiple options should separated by commas.
+                                             example: nas://path/to/mount/:/home/admin/dir/:false.
                                              and it is always using with nas_access_group and nas_file_system.
-                                             example2: oss://path/to/mount/:/home/admin/dir/,
+                                             example2: oss://path/to/mount/:/home/admin/dir/:true,
                                              and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
                 'nas_access_group': 'NAS access groups, multiple items should be separated by comma',
                 'nas_file_system': 'NAS file system, multiple items should be separated by comma',
@@ -178,16 +178,28 @@ def getJSON():
                 'spot_price_limit': 'optional, it\'s available when resource_type is Spot(unit: yuan,works to three decimal places). Set to 0 means using the system automatically bid(But lower than the "OnDemand" price)',
                 'mount': """optional,mount nas path to local file system in read/write mode,
                                              or mount oss path to local file system in read mode.
-                                             format: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
-                                             example: nas://path/to/mount/:/home/admin/dir/.
+                                             format: <nas_path|oss_path>:<dir_path>[:write_support],multiple options should separated by commas.
+                                             example: nas://path/to/mount/:/home/admin/dir/:false.
                                              and it is always using with nas_access_group and nas_file_system.
-                                             example2: oss://path/to/mount/:/home/admin/dir/,
+                                             example2: oss://path/to/mount/:/home/admin/dir/:true,
                                              and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
                 'image': "optional, imageId, type '%s i' for more" % CMD,
                 'type': "optional, instance type, type '%s t' for more" % CMD,
                 'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false'
             }
         },
+        "recreate_cluster_instance": {
+            'description': 'recreate cluster instances',
+            'option': {
+                'yes': "optional, just recreate without confirm",
+            }
+        },
+        "delete_cluster_instance": {
+            'description': 'delete cluster instances',
+            'option': {
+                'yes': "optional, just delete without confirm",
+            }
+        },
         "create_app": {
             'description': 'create App',
             "option": {
@@ -317,10 +329,7 @@ def getJSON():
                 'force': "optional,job don't fail when instance were failed, default: job fail when even one instance were failed",
                 'auto_release': "optional, job will be released (deleted) when finished(job.state=='finished')",
                 'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
-                'read_mount': """optional,mount a oss path to local file system in read-only mode, kv-pairs, multi-supported,
-                                             format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                             mount folder example: oss://bucket/key/:/home/admin/ossdir/,
-                                             mount file example: oss://bucket/key1:/home/admin/key1 """,
+                'read_mount': """optional, it works in the same way as mount """,
                 'write_mount': """optional,mount a oss path to local file system in writable mode
                                              (files in the mounted folder will be upload to oss_path after the task is finished),
                                              kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
@@ -328,10 +337,10 @@ def getJSON():
 
                 'mount': """optional,mount nas path to local file system in read/write mode,
                                              or mount oss path to local file system in read mode.
-                                             format: <nas_path|oss_path>:<dir_path>[,<nas_path2|oss_path2>:<dir_path2>...],
-                                             example: nas://path/to/mount/:/home/admin/dir/.
+                                             format: <nas_path|oss_path>:<dir_path>[:write_support],multiple options should separated by commas.
+                                             example: nas://path/to/mount/:/home/admin/dir/:false.
                                              and it is always using with nas_access_group and nas_file_system.
-                                             example2: oss://path/to/mount/:/home/admin/dir/,
+                                             example2: oss://path/to/mount/:/home/admin/dir/:true,
                                              and file is also supported: oss://path/to/mount/a.txt:/home/admin/dir/a.txt.""",
                 'log_mapping': """optional, the local log file to the oss directory mapping (When the program is running, the files written to the local directory will be uploaded to the corresponding oss_path),
                                              format: <oss_path>:<file_path>[,<oss_path2>:<file_path2>...],
