@@ -46,7 +46,7 @@ def __get_json():
                 'god': "使用上帝模式, 可选范围:[true|false]",
                 'ssl': '使用https访问BatchCompute, 可选范围:[true|false]',
                 'qsubuser': '设置qsub用户名, 如果不设置,默认:root',
-                'vpc_cidr_block': '设置默认使用VPC的CIDR IP段, 一般设置为: 192.168.0.0/16, 如果不设置或者设置为false, 则使用经典网络',
+                'vpc_cidr_block': '设置使用VPC的CIDR IP段, 默认为: 192.168.0.0/16, 如果设置为false, 则使用经典网络' 
             }
         },
         'info': {
