@@ -8,6 +8,8 @@ from ..const import CMD
 import re
 MOUNTS_PROTOCOLS = ['smb://','lustre://','nasplus://', 'nas://','oss://']
 
+FALSE_ARR = ['', 'null', 'None', 'false', 'False','0']
+
 def parse_id_arr(arr, type='jobs', needCheckGod=False):
     t=[]
     arr = _parse_shot_id(arr)
@@ -220,7 +222,9 @@ def trans_mount(s):
 
 
 def trans_docker(docker=None, ignoreErr=False):
-
+    if docker.startswith('registry'):
+        return {"BATCH_COMPUTE_DOCKER_IMAGE": docker}
+    
     ind = docker.find('@oss://')
     if ind > 1:
 
@@ -324,22 +328,10 @@ def set_default_type_n_image():
     config.setConfigs(config.COMMON, m)
 
 
-
-    # if not found default type
-    # or not a available type
     default_type = m.get('defaulttype')
     if not default_type:
         print(yellow('\n  [WARN]: %s\n' % 'defaulttype is recommended to set, use: "bcs set -t <instance_type>", and type "bcs t" to see more'))
 
-    # arr = client.list_instance_types()
-    #
-    # if default_type:
-    #   for n in arr:
-    #     if default_type == n['name']:
-    #       return
-    #
-    # if len(arr)>0:
-    #    m['defaulttype'] = arr[0]['name']
 
 def check_default_vpc_cidr_block():
 
@@ -347,4 +339,7 @@ def check_default_vpc_cidr_block():
 
     vpc_cidr_block = m.get('vpc_cidr_block')
     if not vpc_cidr_block:
-        print(yellow('\n  [WARN]: %s\n' % 'vpc_cidr_block is recommended to set, use "bcs set --vpc_cidr_block [vpc_cidr_block]"'))
+        m['vpc_cidr_block'] = "192.168.0.0/16"
+        print(yellow('\n  [WARN]: default vpc_cidr_block: %s' % m['vpc_cidr_block']))
+        config.setConfigs(config.COMMON, m)
+    
\ No newline at end of file
